@@ -25,14 +25,11 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-chart.h>
-#include <goffice/utils/go-style.h>
+#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/utils/go-color.h>
-#include <goffice/utils/go-styled-object.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-marker.h>
-#include <goffice/utils/go-path.h>
-#include <goffice/utils/go-persist.h>
 #include <goffice/utils/go-units.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -40,14 +37,6 @@
 
 #include <math.h>
 
-/**
- * SECTION: gog-legend
- * @short_description: A legend.
- *
- * A legend shows the name of each #GogSeries and which colors they
- * have in the plot. To use, add in the role "Legend" of a #GogChart.
- */
-
 struct _GogLegend {
 	GogOutlinedObject base;
 
@@ -168,24 +157,23 @@ gog_legend_update (GogObject *obj)
 }
 
 static void
-gog_legend_populate_editor (GogObject *gobj,
-			    GOEditor *editor,
-			    GogDataAllocator *dalloc,
+gog_legend_populate_editor (GogObject *gobj, 
+			    GogEditor *editor, 
+			    GogDataAllocator *dalloc, 
 			    GOCmdContext *cc)
 {
 	static guint legend_pref_page = 0;
 
 	(GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
-	go_editor_set_store_page (editor, &legend_pref_page);
+	gog_editor_set_store_page (editor, &legend_pref_page);
 }
 
 static void
-gog_legend_init_style (GogStyledObject *gso, GOStyle *style)
+gog_legend_init_style (GogStyledObject *gso, GogStyle *style)
 {
-	style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL | GO_STYLE_FONT;
+	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), 0, GO_STYLE_OUTLINE | GO_STYLE_FILL |
-	        GO_STYLE_FONT);
+		style, GOG_OBJECT (gso), 0, FALSE);
 }
 
 static void
@@ -202,7 +190,7 @@ gog_legend_class_init (GogLegendClass *klass)
 	GogStyledObjectClass *style_klass   = (GogStyledObjectClass *) klass;
 
 	parent_klass = g_type_class_peek_parent (klass);
-
+	
 	gobject_klass->set_property = gog_legend_set_property;
 	gobject_klass->get_property = gog_legend_get_property;
 	gog_klass->parent_changed   = gog_legend_parent_changed;
@@ -210,21 +198,21 @@ gog_legend_class_init (GogLegendClass *klass)
 	gog_klass->populate_editor  = gog_legend_populate_editor;
 	gog_klass->view_type        = gog_legend_view_get_type ();
 	style_klass->init_style     = gog_legend_init_style;
-
+	
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	g_object_class_install_property (gobject_klass, LEGEND_SWATCH_SIZE_PTS,
-		g_param_spec_double ("swatch-size-pts",
+		g_param_spec_double ("swatch-size-pts", 
 			_("Swatch Size pts"),
 			_("size of the swatches in pts."),
-			0, G_MAXDOUBLE, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			0, G_MAXDOUBLE, 0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, LEGEND_SWATCH_PADDING_PTS,
-		g_param_spec_double ("swatch-padding-pts",
+		g_param_spec_double ("swatch-padding-pts", 
 			_("Swatch Padding pts"),
 			_("padding between the swatches in pts."),
-			0, G_MAXDOUBLE, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			0, G_MAXDOUBLE, 0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 }
 
 static void
@@ -237,7 +225,7 @@ gog_legend_init (GogLegend *legend)
 
 GSF_CLASS (GogLegend, gog_legend,
 	   gog_legend_class_init, gog_legend_init,
-	   GOG_TYPE_OUTLINED_OBJECT)
+	   GOG_OUTLINED_OBJECT_TYPE)
 
 #define	GLV_ELEMENT_HEIGHT_EM		1.2	/* Legend element height, in font size */
 #define GLV_LINE_WIDTH_MAX_DEFAULT_EM	0.5	/* Maximum sample line width, in font size */
@@ -264,39 +252,39 @@ typedef struct {
 
 typedef GogOutlinedViewClass	GogLegendViewClass;
 
-#define GOG_TYPE_LEGEND_VIEW	(gog_legend_view_get_type ())
-#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LEGEND_VIEW, GogLegendView))
-#define GOG_IS_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LEGEND_VIEW))
+#define GOG_LEGEND_VIEW_TYPE	(gog_legend_view_get_type ())
+#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LEGEND_VIEW_TYPE, GogLegendView))
+#define IS_GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LEGEND_VIEW_TYPE))
 
 static GogViewClass *lview_parent_klass;
 
 static void
-cb_size_elements (unsigned i, GOStyle const *style,
+cb_size_elements (unsigned i, GogStyle const *style, 
 		  char const *name, GogLegendView *glv)
 {
 	GogView *view = GOG_VIEW (glv);
 	GOGeometryAABR aabr;
-
+	
 	gog_renderer_get_text_AABR (view->renderer, name, FALSE, &aabr);
 
 	if (glv->element_width < aabr.w)
 		glv->element_width = aabr.w;
 	if (glv->element_height < aabr.h)
 		glv->element_height = aabr.h;
-	if (!glv->uses_lines && (style->interesting_fields & GO_STYLE_LINE))
+	if (!glv->uses_lines && (style->interesting_fields & GOG_STYLE_LINE)) 
 		glv->uses_lines = TRUE;
 }
 
 static void
-gog_legend_view_size_request (GogView *v,
-			      GogViewRequisition const *available,
+gog_legend_view_size_request (GogView *v, 
+			      GogViewRequisition const *available, 
 			      GogViewRequisition *req)
 {
 	GogChart *chart = GOG_CHART (v->model->parent);
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
 	GogViewRequisition child_req, residual, frame_req;
-	GOStyle *style;
+	GogStyle *style;
 	double available_space, element_size;
 	unsigned num_elements;
 
@@ -314,7 +302,7 @@ gog_legend_view_size_request (GogView *v,
 	gog_chart_get_cardinality (chart, NULL, &num_elements);
 
 	if (num_elements < 1) {
-		/* If there's no child requisition and no element, there's no
+		/* If there's no child requisition and no element, there's no 
 		 * point in displaying a legend box. */
 		if (go_sub_epsilon (child_req.w) <= 0.0 &&
 		    go_sub_epsilon (child_req.h) <= 0.0) {
@@ -326,13 +314,13 @@ gog_legend_view_size_request (GogView *v,
 		return;
 	}
 
-	style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
+	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
 	gog_renderer_push_style (v->renderer, style);
-
+	
 	glv->font_size = pango_font_description_get_size (style->font.font->desc) / PANGO_SCALE;
 	glv->swatch_w = gog_renderer_pt2r_x (v->renderer, glv->font_size);
 	glv->swatch_h = gog_renderer_pt2r_y (v->renderer, glv->font_size);
-
+					     
 	glv->element_width = 0.;
 	glv->element_height = GLV_ELEMENT_HEIGHT_EM * glv->swatch_h;
 	glv->uses_lines = FALSE;
@@ -342,16 +330,16 @@ gog_legend_view_size_request (GogView *v,
 
 	gog_renderer_pop_style (v->renderer);
 
-	glv->label_offset = (glv->uses_lines ?
-			     GLV_LINE_LENGTH_EM + GLV_SWATCH_SPACING_EM :
+	glv->label_offset = (glv->uses_lines ? 
+			     GLV_LINE_LENGTH_EM + GLV_SWATCH_SPACING_EM : 
 			     GLV_SWATCH_LENGTH_EM + GLV_SWATCH_SPACING_EM) * glv->swatch_w;
 	glv->element_width += glv->label_offset + glv->swatch_w * GLV_ELEMENT_SPACING_EM;
 
 	available_space = glv->is_vertical ? residual.h : residual.w;
-	element_size = glv->is_vertical ? glv->element_height : glv->element_width;
-
+	element_size = glv->is_vertical ? glv->element_height : glv->element_width;	
+	
 	glv->element_per_blocks = available_space > 0. ? floor (available_space / element_size) : 0;
-
+	
 	if (glv->element_per_blocks < 1) {
 	       	req->w = req->h = -1;
 		return;
@@ -364,7 +352,7 @@ gog_legend_view_size_request (GogView *v,
 		req->w += glv->num_blocks * glv->element_width - glv->swatch_w * GLV_ELEMENT_SPACING_EM;
 	} else {
 		req->h += glv->num_blocks * glv->element_height;
-		req->w += MIN (glv->element_per_blocks, num_elements) * glv->element_width
+		req->w += MIN (glv->element_per_blocks, num_elements) * glv->element_width 
 			- glv->swatch_w * GLV_ELEMENT_SPACING_EM;
 	}
 
@@ -382,10 +370,10 @@ typedef struct {
 } SwatchScaleClosure;
 
 static void
-cb_swatch_scale (unsigned i, GOStyle const *style, char const *name,
+cb_swatch_scale (unsigned i, GogStyle const *style, char const *name,
 		 SwatchScaleClosure *data)
 {
-	GOStyleLine const *line = NULL;
+	GogStyleLine const *line = NULL;
 	double size;
 	double maximum, scale;
 
@@ -395,8 +383,10 @@ cb_swatch_scale (unsigned i, GOStyle const *style, char const *name,
 	if (data->size_min > size)
 		data->size_min = size;
 
-	if (style->interesting_fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE))
+	if (style->interesting_fields & GOG_STYLE_LINE)
 		line = &style->line;
+	else if (style->interesting_fields & GOG_STYLE_OUTLINE)
+		line = &style->outline;
 
 	if (line == NULL ||
 	    line->width <= data->hairline_width)
@@ -426,22 +416,22 @@ typedef struct {
 	double element_step_x, element_step_y;
 	double block_step_x, block_step_y;
 	GogViewAllocation swatch;
+	ArtVpath line_path[3];
 	double swatch_scale_a, swatch_scale_b;
 	double line_scale_a, line_scale_b;
 	double hairline_width;
 } RenderClosure;
 
 static void
-cb_render_elements (unsigned index, GOStyle const *base_style, char const *name,
+cb_render_elements (unsigned index, GogStyle const *base_style, char const *name,
 		    RenderClosure *data)
 {
 	GogView const *view = data->view;
 	GogLegendView *glv = GOG_LEGEND_VIEW (view);
 	GogRenderer *renderer = view->renderer;
-	GOStyle *style = NULL;
+	GogStyle *style = NULL;
 	GogViewAllocation pos, rectangle;
-	double half_width, y;
-	GOPath *line_path;
+	double half_width;
 
 	if (data->count > 0) {
 		if ((data->count % glv->element_per_blocks) != 0) {
@@ -454,9 +444,8 @@ cb_render_elements (unsigned index, GOStyle const *base_style, char const *name,
 	}
 	data->count++;
 
-	if (base_style->interesting_fields & GO_STYLE_LINE) { /* line and marker */
-		style = go_style_dup (base_style);
-		g_return_if_fail (style != NULL);
+	if (base_style->interesting_fields & GOG_STYLE_LINE) { /* line and marker */
+		style = gog_style_dup (base_style);
 		go_marker_set_size (style->marker.mark,
 				    go_marker_get_size (style->marker.mark) *
 				    data->swatch_scale_a + data->swatch_scale_b);
@@ -465,25 +454,25 @@ cb_render_elements (unsigned index, GOStyle const *base_style, char const *name,
 
 		gog_renderer_push_style (renderer, style);
 		half_width = 0.5 * gog_renderer_line_size (renderer, style->line.width);
-		line_path = go_path_new ();
-		y = data->y + glv->element_height / 2.;
-		go_path_move_to (line_path, data->x + half_width, y);
-		go_path_line_to (line_path, data->x + data->swatch.w * GLV_LINE_LENGTH_EM - half_width, y);
-		if (style->interesting_fields & GO_STYLE_FILL) {
+		data->line_path[0].x = data->x + half_width;
+		data->line_path[1].x = data->x + data->swatch.w * GLV_LINE_LENGTH_EM - half_width;
+		data->line_path[0].y =
+		data->line_path[1].y = data->y + glv->element_height / 2.;
+		if (style->interesting_fields & GOG_STYLE_FILL) {
 			rectangle.x = data->x - half_width;
-			rectangle.y = y;
+			rectangle.y = data->line_path[0].y;
 			rectangle.w = data->swatch.w * GLV_LINE_LENGTH_EM + 2.0 * half_width;
 			rectangle.h = glv->element_height / 2.0;
 			gog_renderer_fill_rectangle (renderer, &rectangle);
 		}
-		gog_renderer_stroke_serie (renderer, line_path);
-		go_path_free (line_path);
-		gog_renderer_draw_marker (renderer, data->x + data->swatch.w  * GLV_LINE_LENGTH_EM * 0.5, y);
+		gog_renderer_draw_path (renderer, data->line_path);
+		gog_renderer_draw_marker (renderer, data->x + data->swatch.w  * GLV_LINE_LENGTH_EM * 0.5,
+					  data->line_path[0].y);
 	} else {					/* area swatch */
-		style = go_style_dup (base_style);
-		if (style->line.width > data->hairline_width)
-			style->line.width =
-				0.5 * (data->hairline_width + style->line.width) * data->line_scale_a +
+		style = gog_style_dup (base_style);
+		if (style->outline.width > data->hairline_width)
+			style->outline.width =
+				0.5 * (data->hairline_width + style->outline.width) * data->line_scale_a +
 				data->line_scale_b;
 
 		rectangle = data->swatch;
@@ -509,7 +498,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 {
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
-	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
+	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
 	RenderClosure data;
 	SwatchScaleClosure swatch_data;
 	double swatch_size_min;
@@ -544,9 +533,9 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 	if (swatch_data.size_min > swatch_size_min)
 		swatch_data.size_min = swatch_size_min;
 	if (go_sub_epsilon (fabs (swatch_data.size_max - swatch_data.size_min)) > 0.0) {
-		data.swatch_scale_a = (swatch_size_max - swatch_size_min) /
+		data.swatch_scale_a = (swatch_size_max - swatch_size_min) / 
 			(swatch_data.size_max - swatch_data.size_min);
-		data.swatch_scale_b = - swatch_data.size_min *
+		data.swatch_scale_b = - swatch_data.size_min * 
 			data.swatch_scale_a +swatch_size_min;
 	} else {
 		data.swatch_scale_a = 1.0;
@@ -557,29 +546,29 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 
 	data.hairline_width = hairline_width;
 
-/*	if (glv->uses_lines) {
+	if (glv->uses_lines) {
 		data.line_path[0].code = ART_MOVETO;
 		data.line_path[1].code = ART_LINETO;
 		data.line_path[2].code = ART_END;
-	}*/
-
+	}
+	
 	data.count = 0;
 	data.view = v;
 	data.x = v->residual.x;
 	data.y = v->residual.y;
 	data.element_step_x = glv->is_vertical ? 0 : glv->element_width;
 	data.element_step_y = glv->is_vertical ? glv->element_height : 0;
-	data.block_step_x = glv->is_vertical ?
-		+ glv->element_width :
+	data.block_step_x = glv->is_vertical ? 
+		+ glv->element_width : 
 		- glv->element_width * (glv->element_per_blocks - 1);
-	data.block_step_y = glv->is_vertical ?
+	data.block_step_y = glv->is_vertical ? 
 		- glv->element_height * (glv->element_per_blocks - 1) :
 		+ glv->element_height;
 	data.swatch.w = glv->swatch_w;
 	data.swatch.h = glv->swatch_h;
 	data.swatch.x = (glv->label_offset - 1.5 * data.swatch.w) * .5;
 	data.swatch.y = (glv->element_height - data.swatch.h) * .5;
-
+	
 	gog_chart_foreach_elem (GOG_CHART (v->model->parent), TRUE,
 		(GogEnumFunc) cb_render_elements, &data);
 
@@ -600,4 +589,4 @@ gog_legend_view_class_init (GogLegendViewClass *gview_klass)
 
 static GSF_CLASS (GogLegendView, gog_legend_view,
 		  gog_legend_view_class_init, NULL,
-		  GOG_TYPE_OUTLINED_VIEW)
+		  GOG_OUTLINED_VIEW_TYPE)
