@@ -20,19 +20,31 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/goffice.h>
+#include <goffice/graph/gog-series-impl.h>
+#include <goffice/graph/gog-data-allocator.h>
+#include <goffice/graph/gog-plot-impl.h>
+#include <goffice/graph/gog-theme.h>
+#include <goffice/graph/gog-style.h>
+#include <goffice/graph/gog-error-bar.h>
+#include <goffice/data/go-data.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
-#include <string.h>
+#ifdef GOFFICE_WITH_GTK
+#include <goffice/gtk/goffice-gtk.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkhseparator.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkvbox.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkcombobox.h>
+#endif
 
-/**
- * SECTION: gog-series
- * @short_description: A single data series.
- *
- * A #GogSeries represents a data series that can be added to a #GogPlot.
- */
+#include <string.h>
 
 /* Keep in sync with GogSeriesFillType enum */
 static struct {
@@ -76,8 +88,8 @@ static void
 gog_series_element_set_index (GogSeriesElement *gse, int ind)
 {
 	gse->index = ind;
-	go_styled_object_apply_theme (GO_STYLED_OBJECT (gse), gse->base.style);
-	go_styled_object_style_changed (GO_STYLED_OBJECT (gse));
+	gog_styled_object_apply_theme (&gse->base, gse->base.style);
+	gog_styled_object_style_changed (&gse->base);
 }
 
 static void
@@ -141,7 +153,7 @@ cb_index_changed (GtkSpinButton *spin_button, GogSeriesElement *element)
 
 static void
 gog_series_element_populate_editor (GogObject *gobj,
-				    GOEditor *editor,
+				    GogEditor *editor,
 			   GogDataAllocator *dalloc,
 			   GOCmdContext *cc)
 {
@@ -167,32 +179,31 @@ gog_series_element_populate_editor (GogObject *gobj,
 	if (gse_vbox == NULL) {
 		vbox = gtk_vbox_new (FALSE, 6);
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-	} else
+	} else 
 		vbox = gse_vbox;
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox), w, 0);
 	gtk_widget_show_all (vbox);
 
 	if (gse_vbox == NULL)
-		go_editor_add_page (editor, vbox, _("Settings"));
+		gog_editor_add_page (editor, vbox, _("Settings"));
 
-	go_editor_set_store_page (editor, &series_element_pref_page);
+	gog_editor_set_store_page (editor, &series_element_pref_page);
 }
 #endif
 
 static void
-gog_series_element_init_style (GogStyledObject *gso, GOStyle *style)
+gog_series_element_init_style (GogStyledObject *gso, GogStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
-	GOStyle *parent_style;
+	GogStyle *parent_style;
 
 	g_return_if_fail (series != NULL);
 
-	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
+	parent_style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
 	style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index,
-	        style->interesting_fields);
+		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
 }
 
 static void
@@ -214,16 +225,16 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 	gog_klass->use_parent_as_proxy  = TRUE;
 
 	g_object_class_install_property (gobject_klass, ELEMENT_INDEX,
-		g_param_spec_int ("index",
+		g_param_spec_int ("index", 
 			_("Index"),
 			_("Index of the corresponding data element"),
 			0, G_MAXINT, 0,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 }
 
-GSF_CLASS_ABSTRACT (GogSeriesElement, gog_series_element,
+GSF_CLASS (GogSeriesElement, gog_series_element,
 	   gog_series_element_class_init, NULL /*gog_series_element_init*/,
-	   GOG_TYPE_STYLED_OBJECT)
+	   GOG_STYLED_OBJECT_TYPE)
 
 /*****************************************************************************/
 
@@ -253,7 +264,6 @@ enum {
 	SERIES_PROP_0,
 	SERIES_PROP_HAS_LEGEND,
 	SERIES_PROP_INTERPOLATION,
-	SERIES_PROP_INTERPOLATION_SKIP_INVALID,
 	SERIES_PROP_FILL_TYPE
 };
 
@@ -274,7 +284,7 @@ role_series_element_allocate (GogObject *series)
 	GogObject *gse;
 
 	if (type == 0)
-		return NULL;
+		type = GOG_SERIES_ELEMENT_TYPE;
 
 	gse = g_object_new (type, NULL);
 	if (gse != NULL)
@@ -287,8 +297,8 @@ static void
 role_series_element_post_add (GogObject *parent, GogObject *child)
 {
 	GogSeries *series = GOG_SERIES (parent);
-	go_styled_object_set_style (GO_STYLED_OBJECT (child),
-		go_styled_object_get_style (GO_STYLED_OBJECT (parent)));
+	gog_styled_object_set_style (GOG_STYLED_OBJECT (child),
+		gog_styled_object_get_style (GOG_STYLED_OBJECT (parent)));
 	series->overrides = g_list_insert_sorted (series->overrides, child,
 		(GCompareFunc) element_compare);
 }
@@ -337,9 +347,6 @@ gog_series_set_property (GObject *obj, guint param_id,
 	case SERIES_PROP_INTERPOLATION:
 		series->interpolation = go_line_interpolation_from_str (g_value_get_string (value));
 		break;
-	case SERIES_PROP_INTERPOLATION_SKIP_INVALID:
-		series->interpolation_skip_invalid = g_value_get_boolean (value);
-		break;
 	case SERIES_PROP_FILL_TYPE:
 		name = g_value_get_string (value);
 		for (i = 0; i < G_N_ELEMENTS (_fill_type_infos); i++)
@@ -367,9 +374,6 @@ gog_series_get_property (GObject *obj, guint param_id,
 	case SERIES_PROP_INTERPOLATION:
 		g_value_set_string (value, go_line_interpolation_as_str (series->interpolation));
 		break;
-	case SERIES_PROP_INTERPOLATION_SKIP_INVALID:
-		g_value_set_boolean (value, series->interpolation_skip_invalid);
-		break;
 	case SERIES_PROP_FILL_TYPE:
 		g_value_set_string (value, _fill_type_infos[series->fill_type].name);
 		break;
@@ -381,10 +385,9 @@ gog_series_get_property (GObject *obj, guint param_id,
 
 #ifdef GOFFICE_WITH_GTK
 static unsigned
-make_dim_editor (GtkTable *table, unsigned row, GogDataEditor *deditor,
+make_dim_editor (GtkTable *table, unsigned row, GtkWidget *editor,
 		 char const *name, GogSeriesPriority priority, gboolean is_shared)
 {
-	GtkWidget *editor = GTK_WIDGET (deditor);
 	char *txt = g_strdup_printf (
 		((priority != GOG_SERIES_REQUIRED) ? "(_%s):" : "_%s:"), _(name));
 	GtkWidget *label = gtk_label_new_with_mnemonic (txt);
@@ -413,25 +416,7 @@ cb_show_in_legend (GtkToggleButton *b, GObject *series)
 static void
 cb_line_interpolation_changed (GtkComboBox *box, GogSeries *series)
 {
-	GtkBuilder *gui = g_object_get_data (G_OBJECT (box), "gui");
-	GtkWidget *widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "skip-button"));
-	GtkWidget *table = go_gtk_builder_get_widget (gui, "clamps-table");
 	series->interpolation = gtk_combo_box_get_active (box);
-	gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
-	widget = GTK_WIDGET (g_object_get_data (G_OBJECT(box), "fill-type"));
-	if (series->interpolation == GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
-		gtk_widget_show (table);
-	else
-		gtk_widget_hide (table);
-	if (widget)
-		gtk_widget_set_sensitive (widget, !go_line_interpolation_auto_skip (series->interpolation));
-	gog_object_emit_changed (GOG_OBJECT (series), FALSE);
-}
-
-static void
-cb_line_interpolation_skip_changed (GtkToggleButton *btn, GogSeries *series)
-{
-	series->interpolation_skip_invalid = gtk_toggle_button_get_active (btn);
 	gog_object_emit_changed (GOG_OBJECT (series), FALSE);
 }
 
@@ -444,7 +429,7 @@ cb_fill_type_changed (GtkComboBox *combo, GObject *obj)
 
 static void
 gog_series_populate_editor (GogObject *gobj,
-			    GOEditor *editor,
+			    GogEditor *editor,
 		   GogDataAllocator *dalloc,
 		   GOCmdContext *cc)
 {
@@ -458,7 +443,6 @@ gog_series_populate_editor (GogObject *gobj,
 	GogDataset *set = GOG_DATASET (gobj);
 	GogSeriesDesc const *desc;
 	GogDataType data_type;
-	GtkComboBox *combo = NULL;
 
 	g_return_if_fail (series->plot != NULL);
 
@@ -519,89 +503,47 @@ gog_series_populate_editor (GogObject *gobj,
 		0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 	gtk_widget_show_all (GTK_WIDGET (table));
 
-	go_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
+	gog_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	box = go_editor_get_registered_widget (editor, "line_box");
+	box = gog_editor_get_registered_widget (editor, "line_box");
 	if (series_class->has_interpolation && box != NULL) {
-		GtkBuilder *gui;
+		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
+		gui = go_libglade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
-			int i;
-			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
-			GogDataset *clamp_set = gog_series_get_interpolation_params (series);
-			widget = go_gtk_builder_get_widget (gui, "interpolation_prefs");
+			widget = glade_xml_get_widget (gui, "interpolation_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
-			widget = go_gtk_builder_get_widget (gui, "interpolation-table");
-			/* create an interpolation type combo and populate it */
-			combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
-			if (set & 1 << GOG_AXIS_RADIAL)
-				for (i = 0; i < GO_LINE_INTERPOLATION_MAX; i++) {
-					if (go_line_interpolation_supports_radial (i))
-						gtk_combo_box_append_text (combo, _(go_line_interpolation_as_label (i)));
-				}
-			else
-				for (i = 0; i < GO_LINE_INTERPOLATION_MAX; i++)
-					gtk_combo_box_append_text (combo, _(go_line_interpolation_as_label (i)));
-			gtk_combo_box_set_active (combo, series->interpolation);
-			g_signal_connect (combo, "changed",
+			widget = glade_xml_get_widget (gui, "interpolation_combo");
+			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), series->interpolation);
+			g_signal_connect (widget, "changed",
 					  G_CALLBACK (cb_line_interpolation_changed), series);
-			gtk_table_attach (GTK_TABLE (widget), GTK_WIDGET (combo), 1, 2,
-					  0, 1, (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-					  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), 0, 0);
-			gtk_widget_show_all (widget);
-			widget = go_gtk_builder_get_widget (gui, "interpolation-skip-invalid");
-			g_object_set_data (G_OBJECT (combo), "skip-button", widget);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), series->interpolation_skip_invalid);
-			if (go_line_interpolation_auto_skip (series->interpolation))
-				gtk_widget_set_sensitive (widget, FALSE);
-			g_signal_connect (widget, "toggled",
-					  G_CALLBACK (cb_line_interpolation_skip_changed), series);
-			if (clamp_set) {
-				GtkWidget *w;
-				widget = go_gtk_builder_get_widget (gui, "clamps-table");
-				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 0, GOG_DATA_SCALAR));
-				gtk_widget_set_tooltip_text (w, _("Derivative at first point of the clamped cubic spline."));
-				gtk_widget_show (w);
-				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-				w = GTK_WIDGET (gog_data_allocator_editor (dalloc, clamp_set, 1, GOG_DATA_SCALAR));
-				gtk_widget_set_tooltip_text (w, _("Derivative at last point of the clamped cubic spline."));
-				gtk_widget_show (w);
-				gtk_table_attach (GTK_TABLE (widget), w, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
-				if (series->interpolation != GO_LINE_INTERPOLATION_CLAMPED_CUBIC_SPLINE)
-					gtk_widget_hide (widget);
-			}
-			g_object_set_data (G_OBJECT (combo), "gui", gui);
-			g_signal_connect_swapped (G_OBJECT (combo), "destroy", G_CALLBACK (g_object_unref), gui);
+			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
+						(GDestroyNotify) g_object_unref);
 		}
 	}
 
-	box = go_editor_get_registered_widget (editor, "fill_extension_box");
+	box = gog_editor_get_registered_widget (editor, "fill_extension_box");
 	if (series_class->has_fill_type && box != NULL) {
-		GtkBuilder *gui;
+		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_gtk_builder_new ("gog-series-prefs.ui", GETTEXT_PACKAGE, cc);
+		gui = go_libglade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
-			widget = go_gtk_builder_get_widget (gui, "fill_type_combo");
+			widget = glade_xml_get_widget (gui, "fill_type_combo");
 			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
 			g_signal_connect (G_OBJECT (widget), "changed",
 					  G_CALLBACK (cb_fill_type_changed), series);
-			if (combo)
-				g_object_set_data (G_OBJECT (combo), "fill-type", widget);
-			if (series->interpolation == GO_LINE_INTERPOLATION_CLOSED_SPLINE)
-				gtk_widget_set_sensitive (widget, FALSE);
-			widget = go_gtk_builder_get_widget (gui, "fill_type_prefs");
+			widget = glade_xml_get_widget (gui, "fill_type_prefs");
 			gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
 			g_object_set_data_full (G_OBJECT (widget), "gui", gui,
 						(GDestroyNotify) g_object_unref);
 		}
 	}
 
-	go_editor_set_store_page (editor, &series_pref_page);
+	gog_editor_set_store_page (editor, &series_pref_page);
 }
 #endif
 
@@ -613,20 +555,12 @@ gog_series_update (GogObject *obj)
 }
 
 static void
-gog_series_child_added (GogObject *parent, GogObject *child)
-{
-	if (GOG_IS_TREND_LINE (child))
-		gog_plot_request_cardinality_update (GOG_SERIES (parent)->plot);
-}
-
-static void
-gog_series_init_style (GogStyledObject *gso, GOStyle *style)
+gog_series_init_style (GogStyledObject *gso, GogStyle *style)
 {
 	GogSeries const *series = (GogSeries const *)gso;
 	style->interesting_fields = series->plot->desc.series.style_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), series->index,
-	        style->interesting_fields);
+		style, GOG_OBJECT (gso), series->index, FALSE);
 }
 
 static void
@@ -672,8 +606,6 @@ gog_series_class_init (GogSeriesClass *klass)
 	gog_klass->populate_editor	= gog_series_populate_editor;
 #endif
 	gog_klass->update		= gog_series_update;
-	gog_klass->child_added		= gog_series_child_added;
-	gog_klass->child_removed	= gog_series_child_added;
 	style_klass->init_style 	= gog_series_init_style;
 	/* series do not have views, so just forward signals from the plot */
 	gog_klass->use_parent_as_proxy  = TRUE;
@@ -681,29 +613,23 @@ gog_series_class_init (GogSeriesClass *klass)
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	g_object_class_install_property (gobject_klass, SERIES_PROP_HAS_LEGEND,
-		g_param_spec_boolean ("has-legend",
+		g_param_spec_boolean ("has-legend", 
 			_("Has-legend"),
 			_("Should the series show up in legends"),
 			TRUE,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
         g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION,
 		 g_param_spec_string ("interpolation",
 			_("Interpolation"),
 			_("Type of line interpolation"),
 			"linear",
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
-	g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION_SKIP_INVALID,
-		g_param_spec_boolean ("interpolation-skip-invalid",
-			_("Interpolation skip invalid"),
-			_("Should the series interpolation ignore the invalid data"),
-			FALSE,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_FILL_TYPE,
-		g_param_spec_string ("fill-type",
+		g_param_spec_string ("fill-type", 
 			_("Fill type"),
 			_("How to fill the area"),
 			"invalid",
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	klass->valid_fill_type_list = NULL;
 
@@ -755,13 +681,14 @@ gog_series_dataset_set_dim (GogDataset *set, int dim_i,
 	GogSeries *series = GOG_SERIES (set);
 	GogGraph *graph = gog_object_get_graph (GOG_OBJECT (series));
 
-	g_return_if_fail (GOG_IS_PLOT (series->plot));
+	g_return_if_fail (IS_GOG_PLOT (series->plot));
 	g_return_if_fail (dim_i >= -1);
 
 	if (dim_i < 0) {
 		char *name = NULL;
 		if (NULL != series->values[-1].data)
-			name = go_data_get_scalar_string (series->values[-1].data);
+			name = g_strdup (go_data_scalar_get_str (
+				GO_DATA_SCALAR (series->values[-1].data)));
 		gog_object_set_name (GOG_OBJECT (series), name, err);
 		return;
 	}
@@ -812,9 +739,9 @@ gog_series_dataset_dim_changed (GogDataset *set, int dim_i)
 		gog_object_request_update (GOG_OBJECT (set));
 	} else {
 		GOData *name_src = series->values[-1].data;
-		char *name = (name_src != NULL)
-			? go_data_get_scalar_string (name_src) : NULL;
-		gog_object_set_name (GOG_OBJECT (set), name, NULL);
+		char const *name = (name_src != NULL)
+			? go_data_scalar_get_str (GO_DATA_SCALAR (name_src)) : NULL;
+		gog_object_set_name (GOG_OBJECT (set), g_strdup (name), NULL);
 	}
 }
 
@@ -829,8 +756,8 @@ gog_series_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogSeries, gog_series,
 		NULL, NULL, gog_series_class_init, NULL,
-		gog_series_init, GOG_TYPE_STYLED_OBJECT, G_TYPE_FLAG_ABSTRACT,
-		GSF_INTERFACE (gog_series_dataset_init, GOG_TYPE_DATASET))
+		gog_series_init, GOG_STYLED_OBJECT_TYPE, 0,
+		GSF_INTERFACE (gog_series_dataset_init, GOG_DATASET_TYPE))
 
 /**
  * gog_series_get_plot :
@@ -841,7 +768,7 @@ GSF_CLASS_FULL (GogSeries, gog_series,
 GogPlot *
 gog_series_get_plot (GogSeries const *series)
 {
-	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
+	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
 	return series->plot;
 }
 
@@ -854,7 +781,7 @@ gog_series_get_plot (GogSeries const *series)
 gboolean
 gog_series_is_valid (GogSeries const *series)
 {
-	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
+	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
 	return series->is_valid;
 }
 
@@ -872,8 +799,8 @@ gog_series_check_validity (GogSeries *series)
 	unsigned i;
 	GogSeriesDesc const *desc;
 
-	g_return_if_fail (GOG_IS_SERIES (series));
-	g_return_if_fail (GOG_IS_PLOT (series->plot));
+	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (IS_GOG_PLOT (series->plot));
 
 	desc = &series->plot->desc.series;
 	for (i = series->plot->desc.series.num_dim; i-- > 0; )
@@ -894,17 +821,17 @@ gog_series_check_validity (GogSeries *series)
 gboolean
 gog_series_has_legend (GogSeries const *series)
 {
-	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
+	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
 	return series->has_legend;
 }
 
 /**
  * gog_series_set_index :
  * @series: #GogSeries
- * @ind: >= 0 assigns a new index, < 0 resets to auto
- * @is_manual: gboolean
+ * @ind:
+ * @is_manual:
  *
- * If @ind >= 0 attempt to assign the new index.  Auto
+ * If @index >= 0 attempt to assign the new index.  Auto
  * indicies (@is_manual == FALSE) will not override the current
  * index if it is manual.  An @index < 0, will reset the index to
  * automatic and potentially queue a revaluation of the parent
@@ -913,7 +840,7 @@ gog_series_has_legend (GogSeries const *series)
 void
 gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 {
-	g_return_if_fail (GOG_IS_SERIES (series));
+	g_return_if_fail (IS_GOG_SERIES (series));
 
 	if (ind < 0) {
 		if (series->manual_index && series->plot != NULL)
@@ -928,8 +855,8 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 		return;
 
 	series->index = ind;
-	go_styled_object_apply_theme (GO_STYLED_OBJECT (series), series->base.style);
-	go_styled_object_style_changed (GO_STYLED_OBJECT (series));
+	gog_styled_object_apply_theme (&series->base, series->base.style);
+	gog_styled_object_style_changed (GOG_STYLED_OBJECT (series));
 }
 
 /**
@@ -941,19 +868,18 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
  *
  * return value: a #GODataScalar, without added reference.
  **/
-GOData *
+GODataScalar *
 gog_series_get_name (GogSeries const *series)
 {
-	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
-
-	return series->values[-1].data;
+	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	return GO_DATA_SCALAR (series->values[-1].data);
 }
 
 /**
  * gog_series_set_name :
  * @series : a #GogSeries
  * @name_src : a #GODataScalar
- * @err : a #GError
+ * @err : a #Gerror
  *
  * Absorbs a ref to @name_src.
  *
@@ -967,9 +893,9 @@ gog_series_set_name (GogSeries *series, GODataScalar *name_src, GError **err)
 /**
  * gog_series_set_dim :
  * @series : #GogSeries
- * @dim_i : Which dimension
+ * @dim_i :
  * @val   : #GOData
- * @err : optional #GError pointer
+ * @err : optional #Gerror pointer
  *
  * Absorbs a ref to @val
  **/
@@ -1003,7 +929,7 @@ gog_series_get_valid_element_index (GogSeries const *series, int old_index, int
 	int index;
 	GList *ptr;
 
-	g_return_val_if_fail (GOG_IS_SERIES (series), -1);
+	g_return_val_if_fail (IS_GOG_SERIES (series), -1);
 
 	if ((desired_index >= (int) series->num_elements) ||
 	    (desired_index < 0))
@@ -1039,21 +965,21 @@ gog_series_get_element (GogSeries const *series, int index)
 	GList *ptr;
 	GogSeriesElement *element;
 
-	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
+	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
 
 	for (ptr = series->overrides; ptr != NULL; ptr = ptr->next) {
 		element = GOG_SERIES_ELEMENT (ptr->data);
 		if ((int) element->index == index)
 			return element;
 	}
-
+	
 	return NULL;
 }
 
 static unsigned int
 gog_series_get_data (GogSeries const *series, int *indices, double **data, int n_vectors)
 {
-	GOData *vector;
+	GODataVector *vector;
 	int i, n_points = 0, vector_n_points;
 	int first, last;
 	int index;
@@ -1067,9 +993,9 @@ gog_series_get_data (GogSeries const *series, int *indices, double **data, int n
 	for (i = 0; i < n_vectors; i++) {
 		index = indices != NULL ? indices[i] : i;
 		if (index >= first && index <= last &&
-		    (vector = series->values[index].data) != NULL) {
-			data[i] = go_data_get_values (vector);
-			vector_n_points = go_data_get_vector_size (vector);
+		    (vector = GO_DATA_VECTOR (series->values[index].data)) != NULL) {
+			data[i] = go_data_vector_get_values (vector);
+			vector_n_points = go_data_vector_get_len (vector);
 			if (!is_set) {
 				is_set = TRUE;
 				n_points = vector_n_points;
@@ -1077,35 +1003,36 @@ gog_series_get_data (GogSeries const *series, int *indices, double **data, int n
 				n_points = MIN (vector_n_points, n_points);
 		} else
 			data[i] = NULL;
-	}
+	}	
 
 	return n_points;
 }
 
 unsigned
 gog_series_get_xy_data (GogSeries const  *series,
-			double const 	**x,
+			double const 	**x, 
 			double const 	**y)
 {
 	GogSeriesClass	*klass = GOG_SERIES_GET_CLASS (series);
 	double *data[2];
 	unsigned int n_points;
-	int first, last;
 
 	g_return_val_if_fail (klass != NULL, 0);
 
 	if (klass->get_xy_data != NULL) {
+		int first, last;
+
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			return 0;
 
+		gog_dataset_dims (GOG_DATASET (series), &first, &last);
+
+		g_return_val_if_fail (first <= 0, 0);
+		g_return_val_if_fail (last >= 1, 0);
+
 		return (klass->get_xy_data) (series, x, y);
 	}
 
-	gog_dataset_dims (GOG_DATASET (series), &first, &last);
-
-	g_return_val_if_fail (first <= 0, 0);
-	g_return_val_if_fail (last >= 1, 0);
-
 	n_points = gog_series_get_data (series, NULL, data, 2);
 
 	*x = data[0];
@@ -1116,8 +1043,8 @@ gog_series_get_xy_data (GogSeries const  *series,
 
 unsigned
 gog_series_get_xyz_data (GogSeries const  *series,
-			 double const 	 **x,
-			 double const 	 **y,
+			 double const 	 **x, 
+			 double const 	 **y, 
 			 double const 	 **z)
 {
 	double *data[3];
@@ -1135,7 +1062,7 @@ gog_series_get_xyz_data (GogSeries const  *series,
 GogSeriesFillType
 gog_series_get_fill_type (GogSeries const *series)
 {
-	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 
 	return series->fill_type;
 }
@@ -1145,7 +1072,7 @@ gog_series_set_fill_type (GogSeries *series, GogSeriesFillType fill_type)
 {
 	GogSeriesClass *series_klass;
 
-	g_return_if_fail (GOG_IS_SERIES (series));
+	g_return_if_fail (IS_GOG_SERIES (series));
 	if (series->fill_type == fill_type)
 		return;
 	g_return_if_fail (fill_type >= 0 && fill_type < GOG_SERIES_FILL_TYPE_INVALID);
@@ -1165,7 +1092,7 @@ gog_series_populate_fill_type_combo (GogSeries const *series, GtkComboBox *combo
 	GogSeriesFillType fill_type;
 	unsigned int i;
 
-	g_return_if_fail (GOG_IS_SERIES (series));
+	g_return_if_fail (IS_GOG_SERIES (series));
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_if_fail (series_klass->valid_fill_type_list != NULL);
 
@@ -1185,22 +1112,10 @@ gog_series_get_fill_type_from_combo (GogSeries const *series, GtkComboBox *combo
 {
 	GogSeriesClass *series_klass;
 
-	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_val_if_fail (series_klass->valid_fill_type_list != NULL, GOG_SERIES_FILL_TYPE_INVALID);
 
 	return series_klass->valid_fill_type_list[gtk_combo_box_get_active (combo)];
 }
 #endif
-
-GogDataset *
-gog_series_get_interpolation_params (GogSeries const *series)
-{
-	GogSeriesClass *series_klass;
-
-	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
-	series_klass = GOG_SERIES_GET_CLASS (series);
-	return (series_klass->get_interpolation_params)?
-			series_klass->get_interpolation_params (series):
-			NULL;
-}
