@@ -28,11 +28,14 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/goffice.h>
+#include "go-color-palette.h"
+#include <goffice/gtk/goffice-gtk.h>
 #include <goffice/utils/go-marshalers.h>
 
+#include <goffice/utils/go-color.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <gdk/gdk.h>
+#include <gdk/gdkcolor.h>
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -73,71 +76,71 @@ enum {
 };
 
 GONamedColor const default_color_set [] = {
-	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x00, 0xff), N_("black")},
-	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x00, 0xff), N_("light brown")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x00, 0xff), N_("brown gold")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x33, 0x00, 0xff), N_("dark green #2")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x33, 0x66, 0xff), N_("navy")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x99, 0xff), N_("purple #2")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x33, 0xff), N_("very dark gray")},
+	{ RGBA_TO_UINT (0x00, 0x00, 0x00, 0xff), N_("black")},
+	{ RGBA_TO_UINT (0x99, 0x33, 0x00, 0xff), N_("light brown")},
+	{ RGBA_TO_UINT (0x33, 0x33, 0x00, 0xff), N_("brown gold")},
+	{ RGBA_TO_UINT (0x00, 0x33, 0x00, 0xff), N_("dark green #2")},
+	{ RGBA_TO_UINT (0x00, 0x33, 0x66, 0xff), N_("navy")},
+	{ RGBA_TO_UINT (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
+	{ RGBA_TO_UINT (0x33, 0x33, 0x99, 0xff), N_("purple #2")},
+	{ RGBA_TO_UINT (0x33, 0x33, 0x33, 0xff), N_("very dark gray")},
 
-	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x00, 0xff), N_("dark red")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x66, 0x00, 0xff), N_("red-orange")},
-	{ GO_COLOR_FROM_RGBA (0x80, 0x80, 0x00, 0xff), N_("gold")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x00, 0xff), N_("dark green")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0xFF, 0xff), N_("blue")},
-	{ GO_COLOR_FROM_RGBA (0x66, 0x66, 0x99, 0xff), N_("dull purple")},
-	{ GO_COLOR_FROM_RGBA (0x80, 0x80, 0x80, 0xff), N_("dark gray")},
+	{ RGBA_TO_UINT (0x80, 0x00, 0x00, 0xff), N_("dark red")},
+	{ RGBA_TO_UINT (0xFF, 0x66, 0x00, 0xff), N_("red-orange")},
+	{ RGBA_TO_UINT (0x80, 0x80, 0x00, 0xff), N_("gold")},
+	{ RGBA_TO_UINT (0x00, 0x80, 0x00, 0xff), N_("dark green")},
+	{ RGBA_TO_UINT (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
+	{ RGBA_TO_UINT (0x00, 0x00, 0xFF, 0xff), N_("blue")},
+	{ RGBA_TO_UINT (0x66, 0x66, 0x99, 0xff), N_("dull purple")},
+	{ RGBA_TO_UINT (0x80, 0x80, 0x80, 0xff), N_("dark gray")},
 
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0x00, 0xff), N_("red")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x99, 0x00, 0xff), N_("orange")},
-	{ GO_COLOR_FROM_RGBA (0x99, 0xCC, 0x00, 0xff), N_("lime")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0x99, 0x66, 0xff), N_("dull green")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0xCC, 0xCC, 0xff), N_("dull blue #2")},
-	{ GO_COLOR_FROM_RGBA (0x33, 0x66, 0xFF, 0xff), N_("sky blue #2")},
-	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x80, 0xff), N_("purple")},
-	{ GO_COLOR_FROM_RGBA (0x96, 0x96, 0x96, 0xff), N_("gray")},
+	{ RGBA_TO_UINT (0xFF, 0x00, 0x00, 0xff), N_("red")},
+	{ RGBA_TO_UINT (0xFF, 0x99, 0x00, 0xff), N_("orange")},
+	{ RGBA_TO_UINT (0x99, 0xCC, 0x00, 0xff), N_("lime")},
+	{ RGBA_TO_UINT (0x33, 0x99, 0x66, 0xff), N_("dull green")},
+	{ RGBA_TO_UINT (0x33, 0xCC, 0xCC, 0xff), N_("dull blue #2")},
+	{ RGBA_TO_UINT (0x33, 0x66, 0xFF, 0xff), N_("sky blue #2")},
+	{ RGBA_TO_UINT (0x80, 0x00, 0x80, 0xff), N_("purple")},
+	{ RGBA_TO_UINT (0x96, 0x96, 0x96, 0xff), N_("gray")},
 
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xCC, 0x00, 0xff), N_("bright orange")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0x00, 0xff), N_("green")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0xCC, 0xFF, 0xff), N_("bright blue")},
-	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x66, 0xff), N_("red purple")},
-	{ GO_COLOR_FROM_RGBA (0xC0, 0xC0, 0xC0, 0xff), N_("light gray")},
+	{ RGBA_TO_UINT (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
+	{ RGBA_TO_UINT (0xFF, 0xCC, 0x00, 0xff), N_("bright orange")},
+	{ RGBA_TO_UINT (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
+	{ RGBA_TO_UINT (0x00, 0xFF, 0x00, 0xff), N_("green")},
+	{ RGBA_TO_UINT (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
+	{ RGBA_TO_UINT (0x00, 0xCC, 0xFF, 0xff), N_("bright blue")},
+	{ RGBA_TO_UINT (0x99, 0x33, 0x66, 0xff), N_("red purple")},
+	{ RGBA_TO_UINT (0xC0, 0xC0, 0xC0, 0xff), N_("light gray")},
 
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x99, 0xCC, 0xff), N_("pink")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xCC, 0x99, 0xff), N_("light orange")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x99, 0xff), N_("light yellow")},
-	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xCC, 0xff), N_("light green")},
-	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xFF, 0xff), N_("light cyan")},
-	{ GO_COLOR_FROM_RGBA (0x99, 0xCC, 0xFF, 0xff), N_("light blue")},
-	{ GO_COLOR_FROM_RGBA (0xCC, 0x99, 0xFF, 0xff), N_("light purple")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0xFF, 0xff), N_("white")},
+	{ RGBA_TO_UINT (0xFF, 0x99, 0xCC, 0xff), N_("pink")},
+	{ RGBA_TO_UINT (0xFF, 0xCC, 0x99, 0xff), N_("light orange")},
+	{ RGBA_TO_UINT (0xFF, 0xFF, 0x99, 0xff), N_("light yellow")},
+	{ RGBA_TO_UINT (0xCC, 0xFF, 0xCC, 0xff), N_("light green")},
+	{ RGBA_TO_UINT (0xCC, 0xFF, 0xFF, 0xff), N_("light cyan")},
+	{ RGBA_TO_UINT (0x99, 0xCC, 0xFF, 0xff), N_("light blue")},
+	{ RGBA_TO_UINT (0xCC, 0x99, 0xFF, 0xff), N_("light purple")},
+	{ RGBA_TO_UINT (0xFF, 0xFF, 0xFF, 0xff), N_("white")},
 
 	{ 0, NULL},
 
 	/* Disable these for now, they are mostly repeats */
-	{ GO_COLOR_FROM_RGBA (0x99, 0x99, 0xFF, 0xff), N_("purplish blue")},
-	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x66, 0xff), N_("red purple")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0xCC, 0xff), N_("light yellow")},
-	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xFF, 0xff), N_("light blue")},
-	{ GO_COLOR_FROM_RGBA (0x66, 0x00, 0x66, 0xff), N_("dark purple")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x80, 0x80, 0xff), N_("pink")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x66, 0xCC, 0xff), N_("sky blue")},
-	{ GO_COLOR_FROM_RGBA (0xCC, 0xCC, 0xFF, 0xff), N_("light purple")},
+	{ RGBA_TO_UINT (0x99, 0x99, 0xFF, 0xff), N_("purplish blue")},
+	{ RGBA_TO_UINT (0x99, 0x33, 0x66, 0xff), N_("red purple")},
+	{ RGBA_TO_UINT (0xFF, 0xFF, 0xCC, 0xff), N_("light yellow")},
+	{ RGBA_TO_UINT (0xCC, 0xFF, 0xFF, 0xff), N_("light blue")},
+	{ RGBA_TO_UINT (0x66, 0x00, 0x66, 0xff), N_("dark purple")},
+	{ RGBA_TO_UINT (0xFF, 0x80, 0x80, 0xff), N_("pink")},
+	{ RGBA_TO_UINT (0x00, 0x66, 0xCC, 0xff), N_("sky blue")},
+	{ RGBA_TO_UINT (0xCC, 0xCC, 0xFF, 0xff), N_("light purple")},
 
-	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
-	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
-	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x80, 0xff), N_("purple")},
-	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x00, 0xff), N_("dark red")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
-	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0xFF, 0xff), N_("blue")},
+	{ RGBA_TO_UINT (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
+	{ RGBA_TO_UINT (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
+	{ RGBA_TO_UINT (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
+	{ RGBA_TO_UINT (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
+	{ RGBA_TO_UINT (0x80, 0x00, 0x80, 0xff), N_("purple")},
+	{ RGBA_TO_UINT (0x80, 0x00, 0x00, 0xff), N_("dark red")},
+	{ RGBA_TO_UINT (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
+	{ RGBA_TO_UINT (0x00, 0x00, 0xFF, 0xff), N_("blue")},
 
 	{ 0, NULL},
 };
@@ -160,7 +163,7 @@ create_color_sel (GObject *action_proxy, GOColor c, GCallback handler, gboolean
 		go_color_to_gdk (c, &gdk));
 	gtk_color_selection_set_has_opacity_control (colorsel, allow_alpha);
 	if (allow_alpha)
-		gtk_color_selection_set_current_alpha (colorsel, GO_COLOR_UINT_A(c) * 257);
+		gtk_color_selection_set_current_alpha (colorsel, UINT_RGBA_A(c) * 257);
 
 	g_signal_connect_object (dialog,
 		"response", handler, action_proxy, 0);
@@ -179,9 +182,9 @@ handle_color_sel (GtkColorSelectionDialog *dialog,
 		guint16 alpha = gtk_color_selection_get_current_alpha (colorsel);
 
 		gtk_color_selection_get_current_color (colorsel, &gdk);
-		*res = GO_COLOR_FROM_GDK (gdk);
+		*res = GDK_TO_UINT (gdk);
 		alpha >>= 8;
-		*res = GO_COLOR_CHANGE_A (*res, alpha);
+		*res = UINT_RGBA_CHANGE_A (*res, alpha);
 	}
 	/* destroy _before_ we emit */
 	gtk_object_destroy (GTK_OBJECT (dialog));
@@ -295,7 +298,7 @@ swatch_activated (GOColorPalette *pal, GtkBin *button)
 
 	g_return_if_fail (swatch != NULL);
 
-	set_color (pal, GO_COLOR_FROM_GDK (swatch->style->bg[GTK_STATE_NORMAL]),
+	set_color (pal, GDK_TO_UINT (swatch->style->bg[GTK_STATE_NORMAL]),
 		   FALSE, TRUE, FALSE);
 }
 
@@ -385,33 +388,30 @@ go_color_palette_set_title (GOColorPalette *pal, char const *title)
 
 /**
  * go_color_palette_set_group :
- * @p : #GOColorPalette
  * @cg : #GOColorGroup
  *
- * Absorbs the reference to the group
- **/
+ * Absorb the reference to the group
+ */
 void
-go_color_palette_set_group (GOColorPalette *p, GOColorGroup *cg)
+go_color_palette_set_group (GOColorPalette *pal, GOColorGroup *cg)
 {
-	if (p->group == cg)
+	if (pal->group == cg)
 		return;
 
-	if (p->group) {
+	if (pal->group) {
 		g_signal_handlers_disconnect_by_func (
-			G_OBJECT (p->group),
-			G_CALLBACK (cb_history_changed), p);
-		g_object_unref (G_OBJECT (p->group));
-		p->group = NULL;
+			G_OBJECT (pal->group),
+			G_CALLBACK (cb_history_changed), pal);
+		g_object_unref (G_OBJECT (pal->group));
+		pal->group = NULL;
 	}
 	if (cg != NULL) {
-		g_object_ref (cg);
-		p->group = cg;
+		pal->group = cg;
 		g_signal_connect_swapped (G_OBJECT (cg),
 			"history-changed",
-			G_CALLBACK (cb_history_changed), p);
+			G_CALLBACK (cb_history_changed), pal);
 	}
 }
-
 static GtkWidget *
 go_color_palette_setup (GOColorPalette *pal,
 		     char const *no_color_label,
@@ -496,25 +496,17 @@ go_color_palette_set_allow_alpha (GOColorPalette *pal, gboolean allow_alpha)
 	pal->allow_alpha = allow_alpha;
 }
 
-/**
- * go_color_palette_new:
- * @no_color_label: color label
- * @default_color: #GOColor
- * @cg: #GOColorGroup
- *
- * Returns: A new palette
- **/
 GtkWidget *
 go_color_palette_new (char const *no_color_label,
-		      GOColor default_color,
-		      GOColorGroup *cg)
+		   GOColor default_color,
+		   GOColorGroup *cg)
 {
 	GOColorPalette *pal;
 	int const cols = 8;
 	int const rows = 6;
 	GONamedColor const *color_names = default_color_set;
 
-	pal = g_object_new (GO_TYPE_COLOR_PALETTE, NULL);
+	pal = g_object_new (GO_COLOR_PALETTE_TYPE, NULL);
 
 	pal->default_set   = color_names;
 	pal->default_color = default_color;
@@ -573,12 +565,6 @@ static GSF_CLASS (GOMenuColor, go_menu_color,
 		  go_menu_color_class_init, NULL,
 		  GTK_TYPE_MENU)
 
-static void
-cb_menu_item_toggle_size_request (GtkWidget *item, gint *requitision)
-{
-	*requitision = 1;
-}
-
 static GtkWidget *
 make_colored_menu_item (char const *label, GOColor c)
 {
@@ -601,10 +587,6 @@ make_colored_menu_item (char const *label, GOColor c)
 	gtk_widget_show_all (button);
 
 	g_object_set_data (G_OBJECT (button), "go_color", GINT_TO_POINTER (c));
-
-	/* Workaround for bug http://bugzilla.gnome.org/show_bug.cgi?id=585421 */
-	g_signal_connect (button, "toggle-size-request", G_CALLBACK (cb_menu_item_toggle_size_request), NULL);
-
 	return button;
 }
 
@@ -650,13 +632,13 @@ cb_menu_custom_activate (GtkWidget *button, GOMenuColor *menu)
 /**
  * go_color_palette_make_menu:
  * @no_color_label: color label
- * @default_color: #GOColor
- * @cg: #GOColorGroup
- * @custom_dialog_title : optional string
+ * default_color: #GOColor
+ * @color_group: #GOColorGroup
+ * @custom_dialog_title :
  * @current_color : #GOColor
  *
- * Returns:  a submenu with a palette of colours.  Caller is responsible for
- * 	creating an item to point to the submenu.
+ * Create a submenu with a palette of colours.  Caller is responsible for
+ * creating an item to point to the submenu.
  **/
 GtkWidget *
 go_color_palette_make_menu (char const *no_color_label,
@@ -708,11 +690,8 @@ custom_colors :
 			G_CALLBACK (cb_menu_color_activate), submenu);
 	}
 	w = gtk_image_menu_item_new_with_label (_("Custom Color..."));
-	/* Workaround for bug http://bugzilla.gnome.org/show_bug.cgi?id=585421 */
-	/* We can't have an image in one of the gtk_menu_item, it would lead to an 
-	   ugly item spacing. */
-	/* gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w),*/
-	/* 	gtk_image_new_from_stock (GTK_STOCK_SELECT_COLOR, GTK_ICON_SIZE_MENU));*/
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (w),
+		gtk_image_new_from_stock (GTK_STOCK_SELECT_COLOR, GTK_ICON_SIZE_MENU));
 	gtk_widget_show_all (w);
 	gtk_menu_attach (GTK_MENU (submenu), w, 0, cols, row + 2, row + 3);
 	g_signal_connect (G_OBJECT (w),
