@@ -134,14 +134,12 @@ time_t
 datetime_serial_to_timet (int serial, GODateConventions const *conv)
 {
 	GDate gd;
+	struct tm tm;
 
 	datetime_serial_to_g (&gd, serial, conv);
-	if (g_date_valid (&gd)) {
-		struct tm tm;
-		g_date_to_struct_tm (&gd, &tm);
-		return mktime (&tm);
-	} else
-		return -1;
+	g_date_to_struct_tm (&gd, &tm);
+
+	return mktime (&tm);
 }
 
 /* ------------------------------------------------------------------------- */
