@@ -31,12 +31,11 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-axis.h>
-#include <goffice/utils/go-style.h>
+#include <goffice/graph/gog-style.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-format.h>
-#include <goffice/utils/go-persist.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #include <glib/gi18n-lib.h>
@@ -189,10 +188,12 @@ gog_plot1_5d_update (GogObject *obj)
 			if (gog_error_bar_is_visible (series->errors))
 				gog_error_bar_get_minmax (series->errors, &minima, &maxima);
 			else
-				go_data_get_bounds (series->base.values[1].data, &minima, &maxima);
+				go_data_vector_get_minmax (GO_DATA_VECTOR (
+					series->base.values[1].data), &minima, &maxima);
 			if (series->base.plot->desc.series.num_dim == 3) {
 				double tmp_min, tmp_max;
-				go_data_get_bounds (series->base.values[2].data, &tmp_min, &tmp_max);
+				go_data_vector_get_minmax (GO_DATA_VECTOR (
+					series->base.values[2].data), &tmp_min, &tmp_max);
 				if (minima > tmp_min )
 					minima = tmp_min;
 				if (maxima < tmp_max)
@@ -205,7 +206,6 @@ gog_plot1_5d_update (GogObject *obj)
 		}
 		if (model->fmt == NULL)
 			model->fmt = go_data_preferred_fmt (series->base.values[1].data);
-		model->date_conv = go_data_date_conv (series->base.values[1].data);
 		index_dim = GOG_SERIES (series)->values[0].data;
 	}
 	axis = gog_plot1_5d_get_index_axis (model);
@@ -235,13 +235,16 @@ gog_plot1_5d_update (GogObject *obj)
 			series = ptr->data;
 			/* we are guaranteed that at least 1 series is valid above */
 			if (!gog_series_is_valid (GOG_SERIES (series))) {
+				lengths[i] = 0;
 				continue;
 			}
-			vals[i] = go_data_get_values (series->base.values[1].data);
+			vals[i] = go_data_vector_get_values (
+				GO_DATA_VECTOR (series->base.values[1].data));
 			g_object_get (G_OBJECT (series), "errors", errors + i, NULL);
 			if (errors[i])
 				g_object_unref (errors[i]);
-			lengths[i] = go_data_get_vector_size (series->base.values[1].data);
+			lengths[i] = go_data_vector_get_len (
+				GO_DATA_VECTOR (series->base.values[1].data));
 
 			i++;
 		}
@@ -282,10 +285,6 @@ gog_plot1_5d_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			}
 		} else if (bounds->fmt == NULL && model->fmt != NULL)
 			bounds->fmt = go_format_ref (model->fmt);
-
-		if (model->date_conv)
-			bounds->date_conv = model->date_conv;
-
 		return NULL;
 	} else if (axis == gog_axis_get_atype (gog_plot1_5d_get_index_axis (model))) {
 		GSList *ptr;
@@ -311,12 +310,6 @@ gog_1_5d_supports_vary_style_by_element (GogPlot const *plot)
 	GogPlot1_5d *gog_1_5d = GOG_PLOT1_5D (plot);
 	return gog_1_5d->type == GOG_1_5D_NORMAL;
 }
-static gboolean
-gog_1_5d_enum_in_reverse (GogPlot const *plot)
-{
-	GogPlot1_5d *gog_1_5d = GOG_PLOT1_5D (plot);
-	return gog_1_5d->type != GOG_1_5D_NORMAL; /* stacked or percentage */
-}
 
 static void
 gog_plot1_5d_class_init (GogPlotClass *plot_klass)
@@ -334,13 +327,13 @@ gog_plot1_5d_class_init (GogPlotClass *plot_klass)
 			_("Type"),
 			_("How to group multiple series, normal, stacked, as_percentage"),
 			"normal", 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, GOG_1_5D_PROP_IN_3D,
 		g_param_spec_boolean ("in-3d", 
 			_("In 3d"),
 			_("Placeholder to allow us to round trip pseudo 3d state"),
 			FALSE, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	gog_klass->update	= gog_plot1_5d_update;
 
@@ -359,19 +352,18 @@ gog_plot1_5d_class_init (GogPlotClass *plot_klass)
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
 	}
+	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = G_MAXINT;
 	plot_klass->series_type = gog_series1_5d_get_type ();
 	plot_klass->axis_get_bounds   	= gog_plot1_5d_axis_get_bounds;
 	plot_klass->axis_set	      	= GOG_AXIS_SET_XY;
 	plot_klass->supports_vary_style_by_element = gog_1_5d_supports_vary_style_by_element;
-	plot_klass->enum_in_reverse	= gog_1_5d_enum_in_reverse;
 }
 
 static void
 gog_plot1_5d_init (GogPlot1_5d *plot)
 {
 	plot->fmt = NULL;
-	plot->date_conv = NULL;
 	plot->in_3d = FALSE;
 	plot->support_series_lines = FALSE;
 	plot->support_drop_lines = FALSE;
@@ -380,7 +372,7 @@ gog_plot1_5d_init (GogPlot1_5d *plot)
 
 GSF_DYNAMIC_CLASS_ABSTRACT (GogPlot1_5d, gog_plot1_5d,
 	gog_plot1_5d_class_init, gog_plot1_5d_init,
-	GOG_TYPE_PLOT)
+	GOG_PLOT_TYPE)
 
 /*****************************************************************************/
 
@@ -489,16 +481,18 @@ gog_series1_5d_update (GogObject *obj)
 	unsigned old_num = series->base.num_elements;
 
 	if (series->base.values[1].data != NULL) {
-		vals = go_data_get_values (series->base.values[1].data);
-		len = go_data_get_vector_size (series->base.values[1].data);
+		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
+		len = go_data_vector_get_len 
+			(GO_DATA_VECTOR (series->base.values[1].data));
 	}
 	series->base.num_elements = len;
 
 	if (series->base.plot->desc.series.num_dim == 3) {
 		int tmp = 0;
 		if (series->base.values[2].data != NULL) {
-			vals = go_data_get_values (series->base.values[2].data);
-			tmp = go_data_get_vector_size (series->base.values[2].data);
+			vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[2].data));
+			tmp = go_data_vector_get_len 
+				(GO_DATA_VECTOR (series->base.values[2].data));
 		}
 		if (tmp < len)
 			len = tmp;
@@ -556,10 +550,10 @@ gog_series1_5d_get_property (GObject *obj, guint param_id,
 }
 
 #ifdef GOFFICE_WITH_GTK
-#include <gtk/gtk.h>
+#include <gtk/gtklabel.h>
 static void 
 gog_series1_5d_populate_editor (GogObject *obj,
-				GOEditor *editor,
+				GogEditor *editor,
 				GogDataAllocator *dalloc,
 				GOCmdContext *cc)
 {
@@ -577,8 +571,7 @@ gog_series1_5d_populate_editor (GogObject *obj,
 	else
 		g_object_get (G_OBJECT (series->plot), "horizontal", &horizontal, NULL);
 	error_page = gog_error_bar_prefs (series, "errors", horizontal, dalloc, cc);
-	go_editor_add_page (editor, error_page, _("Error bars"));
-	g_object_unref (error_page);
+	gog_editor_add_page (editor, error_page, _("Error bars"));
 }
 #endif
 
@@ -642,8 +635,8 @@ gog_series1_5d_class_init (GogObjectClass *obj_klass)
 		g_param_spec_object ("errors", 
 			_("Error bars"),
 			_("GogErrorBar *"),
-			GOG_TYPE_ERROR_BAR, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GOG_ERROR_BAR_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 }
 
 static void
@@ -660,7 +653,7 @@ gog_series1_5d_init (GObject *obj)
 
 GSF_DYNAMIC_CLASS (GogSeries1_5d, gog_series1_5d,
 	gog_series1_5d_class_init, gog_series1_5d_init,
-	GOG_TYPE_SERIES)
+	GOG_SERIES_TYPE)
 
 /* Plugin initialization */
 
@@ -672,13 +665,10 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_series1_5d_register_type (module);
 	gog_barcol_plot_register_type (module);
 	gog_barcol_view_register_type (module);
-	gog_barcol_series_register_type (module);
-	gog_barcol_series_element_register_type (module);
 	gog_dropbar_plot_register_type (module);
 	gog_dropbar_view_register_type (module);
 	gog_line_series_register_type (module);
 	gog_line_series_view_register_type (module);
-	gog_line_series_element_register_type (module);
 	gog_line_plot_register_type (module);
 	gog_area_plot_register_type (module);
 	gog_line_view_register_type (module);
