@@ -21,8 +21,8 @@
 
 #include <goffice/goffice-config.h>
 #include "gog-log-reg.h"
-#include <goffice/utils/go-math.h>
-#include <goffice/utils/go-regression.h>
+#include <goffice/math/go-math.h>
+#include <goffice/math/go-regression.h>
 #include <glib/gi18n-lib.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -36,11 +36,9 @@ gog_log_reg_curve_build_values (GogLinRegCurve *rc, double const *x_vals, double
 	gog_reg_curve_get_bounds (&rc->base, &xmin, &xmax);
 	if (rc->x_vals == NULL)
 		rc->x_vals = g_new0 (double*, 1);
-	if (*rc->x_vals != NULL)
-		g_free (*rc->x_vals);
+	g_free (*rc->x_vals);
 	*rc->x_vals = g_new (double, n);
-	if (rc->y_vals != NULL)
-		g_free (rc->y_vals);
+	g_free (rc->y_vals);
 	rc->y_vals = g_new (double, n);
 	for (i = 0, used = 0; i < n; i++) {
 		x = (x_vals)? x_vals[i]: i;
